# Configuration après l'installation de Archlinux

## Configuration des applications

### Firefox

uBlock Origin, Privacy Badger, Grammalecte dans les Archlinux Community

### Libre Office

Grammalecte -> [https://grammalecte.net/#download](https://grammalecte.net/#download)

Pour préformater les pages en A4 (paquet libpaper):
```
sudo paperconfig -p a4
```
Récupérer le dossier `~/.config/libreoffice` sauvegardé. 

### Oh my zsh !

[https://ohmyz.sh](https://ohmyz.sh)
[https://github.com/ohmyzsh/ohmyzsh](https://github.com/ohmyzsh/ohmyzsh)

Tuto video : [https://www.youtube.com/watch?v=3KzIQFPWs2Y](https://www.youtube.com/watch?v=3KzIQFPWs2Y)

Installer depuis [https://ohmyz.sh/](https://ohmyz.sh/).
<br>
Pour les plugins voir [https://github.com/zsh-users](https://github.com/zsh-users) :

* [zsh-syntax-highlighting](https://github.com/zsh-users/zsh-syntax-highlighting);
* [zsh-autosuggestions](https://github.com/zsh-users/zsh-autosuggestions);
* [zsh-completions](https://github.com/zsh-users/zsh-completions).

Cloner les plugins puis les déplacer dans le dossier ~/.oh-my-zsh/plugins :

```
mv zsh* .oh-my-zsh/plugins
```

Il faut ensuite signaler les plugins dans la partie :

```
nano .zshrc

```
puis :
```
plugins=(git
zsh-syntax-highlighting
zsh-completions
zsh-autosuggestions
)
```

##### Installer un thème Zsh

Pour installer le thème "powerlevel10k", il faut cloner le git suivant : [https://github.com/romkatv/powerlevel10k.git](https://github.com/romkatv/powerlevel10k)
et le déplacer dans ~/.oh-my-zsh/themes :

```
mv powerlevel10k .oh-my-zsh/themes 
```

Éditer et relancer ~/.zshrc -> *ZSH_THEME="powerlevel10k/powerlevel10k"*

```
nano .zshrc
source .zshrc
```

Éditer et relancer ~/.p10k.zsh pour paramétrer -> tout commenter sauf :

* status, command_execution_time, background_jobs, direnv, load, disk_usage, ram, swap

```
nano .p10k.zsh
source .p10k.zsh
```
![Thème du Terminal](/img/Terminal1.png)

### Configuration de pacman.conf
Pour ajouter plus d'effets visuel à Pacman voici deux proposition suivantes à inclure dans le fichiers `/etc/pacman.conf`:
- ajouter "ILoveCandy" dans le paragraphe [options];
- décommenter toutes les options dans la partie #Misc options.

### Rhythmbox
Logiciel de lecture audio et de gestion des fichiers de la discothèque.
En cas de réinstallation de l'OS il est possible de conserver la base de données de Rhythmbox (bibliothèque, notations…). Cette manipulation ne fonctionne que si les fichiers musicaux restent aux mêmes emplacements.

Sauvegarder le dossier caché `~/.local/share/rhythmbox`, puis de le restaurer après la réinstallation.

- [https://doc.ubuntu-fr.org/rhythmbox](https://doc.ubuntu-fr.org/rhythmbox)
- [https://wiki.archlinux.org/title/Rhythmbox](https://wiki.archlinux.org/title/Rhythmbox)

### Thunderbird

Ajouter l'extension "Grammalecte".

### UFW
```
ufw default deny
ufw allow from 192.168.0.0/24
ufw allow Deluge
ufw limit ssh
ufw enable

ufw status
```

### Youtube-dl

Petit programme en ligne de commande pour récupérer les flux de vidéos depuis internet (notamment Arte).

[Tuto Ubuntu](http://doc.ubuntu-fr.org/youtube-dl)

[Manuel Ubuntu](http://manpages.ubuntu.com/manpages/focal/en/man1/youtube-dl.1.html) (en)

### HexChat

Client IRC pour suivre l'actualité de `#archlinux-fr, archlinux-aur, archlinux-br, archlinux-es, archlinux-pt, archlinux-ve, archlinux-women, archlinux-niewbie, archlinux-wiki`

## Installer et utiliser plusieurs noyaux sur Archlinux

### Installer le noyaux linux-lts

D'après la vidéo tuto de F. Beziès : [https://www.youtube.com/watch?v=LIYCeBDIy5w](https://www.youtube.com/watch?v=LIYCeBDIy5w)

Pour connaitre le noyaux linux qui est installé :

```
uname -a
```

On installe le noyaux linux-lts, plus stable, en cas de problème avec le noyaux principal :

```
$ sudo pacman -S linux-lts linux-lts-headers
```

Pour vérifier que les trois noyaux soient bien installés :

```
ls /boot
```

Pour intervenir dans le grub afin que les noyaux apparaissent dans le chargeur de démarrage :

```
sudo grub-mkconfig -o /boot/grub/grub.cfg
```

## Modifier l'entrée par défaut dans le grub

- [https://wiki.archlinux.fr/GRUB/Trucs_et_Astuces#Entr.C3.A9es_Multiples](https://wiki.archlinux.fr/GRUB/Trucs_et_Astuces#Entr.C3.A9es_Multiples)

- [https://doc.ubuntu-fr.org/tutoriel/grub2_parametrage_manuel#menu_par_defaut](https://doc.ubuntu-fr.org/tutoriel/grub2_parametrage_manuel#menu_par_defaut)

### Mémorisation du dernier choix

GRUB peut se souvenir de la dernière entrée démarrée et l'utiliser comme entrée de démarrage par défaut pour la prochaine fois. Pour ce faire, éditez `/etc/default/grub` et modifiez la valeur de GRUB_DEFAULT:

```
GRUB_DEFAULT=saved
```

Ceci garantit que GRUB passe par défaut à l'entrée sauvegardée. Pour activer la sauvegarde de l'entrée sélectionnée, ajoutez la ligne suivante à `/etc/default/grub`:

```
GRUB_SAVEDEFAULT=true
```
### Changer l'entrée par défaut du menu

Pour changer l'entrée par défaut du menu, éditer `/etc/default/grub` et modifier la valeur de `GRUB_DEFAULT`:

En utilisant les titres :

```
GRUB_DEFAULT='Advanced options for Arch Linux>Arch Linux, with Linux linux'
```

En utilisant les nombres :

```
GRUB_DEFAULT="1>2"
```

Grub identifie les entrées du menu généré par comptage depuis zero. Ce qui signifie 0 pour la première entrée qui est celle par défaut, 1 pour la deuxième et ainsi de suite. Les entrées du menu principal et des sous-menus sont séparées par un >.

L'exemple ci-dessus démarre la troisième entrée du menu principal : 'Advanced options for Arch Linux'.

Il faut ensuite recharger le grub :

```
sudo grub-mkconfig -o /boot/grub/grub.cfg
```

## Personnalisation du système

### Cinnamon
[https://framagit.org/nodiego/archlinux-cool/-/blob/master/cinnamon.md](https://framagit.org/nodiego/archlinux-cool/-/blob/master/cinnamon.md)
